@@ -6,15 +6,17 @@ package render_test
 import (
 	"testing"
 
+	"github.com/derailed/k9s/internal/model1"
 	"github.com/derailed/k9s/internal/render"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestRoleRender(t *testing.T) {
 	c := render.Role{}
-	r := render.NewRow(3)
+	r := model1.NewRow(3)
 
-	assert.NoError(t, c.Render(load(t, "ro"), "", &r))
+	require.NoError(t, c.Render(load(t, "ro"), "", &r))
 	assert.Equal(t, "default/blee", r.ID)
-	assert.Equal(t, render.Fields{"default", "blee"}, r.Fields[:2])
+	assert.Equal(t, model1.Fields{"default", "blee"}, r.Fields[:2])
 }
