@@ -107,8 +107,8 @@ func (s *SelectTable) SelectRow(r, c int, broadcast bool) {
 	if !broadcast {
 		s.SetSelectionChangedFunc(nil)
 	}
-	if c := s.model.RowCount(); c > 0 && r-1 > c {
-		r = c + 1
+	if count := s.model.RowCount(); count > 0 && r-1 > count {
+		r = count + 1
 	}
 	defer s.SetSelectionChangedFunc(s.selectionChanged)
 	s.Select(r, c)
