@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package xray_test
 
 import (
@@ -5,8 +8,10 @@ import (
 	"testing"
 
 	"github.com/derailed/k9s/internal"
+	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/xray"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 	metav1beta1 "k8s.io/apimachinery/pkg/apis/meta/v1beta1"
 )
 
@@ -25,11 +30,11 @@ func TestGenericRender(t *testing.T) {
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			root := xray.NewTreeNode("generics", "generics")
+			root := xray.NewTreeNode(client.NewGVR("generic"), "generics")
 			ctx := context.WithValue(context.Background(), xray.KeyParent, root)
 			ctx = context.WithValue(ctx, internal.KeyFactory, makeFactory())
 
-			assert.Nil(t, re.Render(ctx, "", makeTable()))
+			require.NoError(t, re.Render(ctx, "", makeTable()))
 			assert.Equal(t, u.level1, root.CountChildren())
 		})
 	}
@@ -39,6 +44,6 @@ func TestGenericRender(t *testing.T) {
 
 func makeTable() metav1beta1.TableRow {
 	return metav1beta1.TableRow{
-		Cells: []interface{}{"fred", "blee"},
+		Cells: []any{"fred", "blee"},
 	}
 }
